package models_utils

import (
	"database/sql"
	"errors"
)

type BaseModel struct {
	Name   string
	Status int
	Id     string

	ImageMode int
	Width     int
	Height    int
}

const (
	FAILED_TRAINING           = -4
	FAILED_PREPARING_TRAINING = -3
	FAILED_PREPARING_ZIP_FILE = -2
	FAILED_PREPARING          = -1

	PREPARING            = 1
	CONFIRM_PRE_TRAINING = 2
	PREPARING_ZIP_FILE   = 3
	TRAINING             = 4
	READY                = 5
)

var ModelNotFoundError = errors.New("Model not found error")

func GetBaseModel(db *sql.DB, id string) (base *BaseModel, err error) {
	rows, err := db.Query("select name, status, id, width, height, color_mode from models where id=$1;", id)
	if err != nil {
		return
	}
	defer rows.Close()

	if !rows.Next() {
		return nil, ModelNotFoundError
	}

	base = &BaseModel{}
	var colorMode string
	err = rows.Scan(&base.Name, &base.Status, &base.Id, &base.Width, &base.Height, &colorMode)
	if err != nil {
		return nil, err
	}

	switch colorMode {
	case "greyscale":
		base.ImageMode = 1
	default:
		panic("unkown color mode")
	}
	return
}
